@@ -1,7 +1,8 @@
 import logging
+import sys
 
 from datetime import datetime
-from typing import List, Dict, Any, Union, Optional, no_type_check
+from typing import List, Dict, Any, Union, Optional, no_type_check, Tuple
 from collections import defaultdict
 from pathlib import Path
 import tempfile
@@ -26,11 +27,14 @@ from capella_console_client.assets import (
     _gather_download_requests,
     _get_asset_bytesize,
     _derive_stac_id,
+    _filter_assets_by_product_types,
 )
 from capella_console_client.search import _build_search_payload, _paginated_search
 from capella_console_client.validate import (
     _validate_uuid,
     _validate_stac_id_or_stac_items,
+    _validate_and_filter_product_types,
+    _validate_and_filter_asset_types,
 )
 
 
@@ -64,15 +68,20 @@ class CapellaConsoleClient:
         verbose: bool = False,
         no_token_check: bool = False,
         base_url: Optional[str] = CONSOLE_API_URL,
+        no_auth: bool = False,
     ):
+        self._set_verbosity(verbose)
+        self._sesh = CapellaConsoleSession(base_url=base_url, verbose=verbose)
+
+        if not no_auth:
+            self._sesh.authenticate(email, password, token, no_token_check)
+
+    def _set_verbosity(self, verbose: bool = False):
         self.verbose = verbose
         logger.setLevel(logging.WARNING)
         if verbose:
             logger.setLevel(logging.INFO)
 
-        self._sesh = CapellaConsoleSession(base_url=base_url, verbose=verbose)
-        self._sesh.authenticate(email, password, token, no_token_check)
-
     # USER
     def whoami(self) -> Dict[str, Any]:
         """
@@ -86,6 +95,59 @@ class CapellaConsoleClient:
         return resp.json()
 
     # TASKING
+    def list_tasking_requests(
+        self,
+        *tasking_request_ids: Optional[str],
+        for_org: Optional[bool] = False,
+        status: Optional[str] = None,
+    ) -> List[Dict[str, Any]]:
+        """
+        list tasking requests
+
+        Args:
+            tasking_request_ids: list only specific tasking_request_ids (variadic, specify multiple)
+            for_org: list all tasking requests of your organization (instead of only yours) - **requires** organization index/ admin permission
+            status: list only tasking requests that are in this/ have passed this status, e.g. completed
+
+        Returns:
+            List[Dict[str, Any]]: metadata of tasking requests
+        """
+        tasking_request_meta = []
+
+        if tasking_request_ids:
+            for t_req_id in tasking_request_ids:
+                _validate_uuid(t_req_id)
+
+        # get selected
+        if tasking_request_ids:
+            tasking_request_meta = [
+                self.get_task(t_req_id) for t_req_id in tasking_request_ids  # type: ignore
+            ]
+            if status:
+                tasking_request_meta = [
+                    t_meta
+                    for t_meta in tasking_request_meta
+                    if self._task_contains_status(t_meta, status)
+                ]
+            return tasking_request_meta
+
+        if for_org:
+            params = {"organizationId": self._sesh.organization_id}
+        else:
+            params = {"customerId": self._sesh.customer_id}
+
+        with self._sesh as session:
+            resp = session.get("/tasks", params=params)
+        tasking_request_meta = resp.json()
+
+        if status:
+            tasking_request_meta = [
+                t_meta
+                for t_meta in tasking_request_meta
+                if self._task_contains_status(t_meta, status)
+            ]
+        return tasking_request_meta
+
     def get_task(self, tasking_request_id: str) -> Dict[str, Any]:
         """
         fetch task for the specified `tasking_request_id`
@@ -101,12 +163,16 @@ class CapellaConsoleClient:
 
         return task_response.json()
 
+    def _task_contains_status(self, task: Dict[str, Any], status_name: str) -> bool:
+        return status_name.lower() in (
+            s["code"] for s in task["properties"]["statusHistory"]
+        )
+
     def is_task_completed(self, task: Dict[str, Any]) -> bool:
         """
         check if a task has completed
         """
-        all_statuses = (s["code"] for s in task["properties"]["statusHistory"])
-        return "completed" in all_statuses
+        return self._task_contains_status(task, "completed")
 
     def get_collects_for_task(self, tasking_request_id: str) -> List[Dict[str, Any]]:
         """
@@ -263,7 +329,9 @@ class CapellaConsoleClient:
                 logger.warning(
                     "setting omit_search=True only works in combination providing items instead of stac_ids"
                 )
-            stac_items = items  # type: ignore
+                stac_items = self.search(ids=stac_ids)
+            else:
+                stac_items = items  # type: ignore
 
         if not stac_items:
             raise NoValidStacIdsError(f"No valid STAC IDs in {', '.join(stac_ids)}")
@@ -308,10 +376,6 @@ class CapellaConsoleClient:
         Args:
             stac_ids: STAC IDs that active order should include
         """
-
-        if not stac_ids:
-            raise ValueError("Please provide at least one stac_id")
-
         order_id = None
         active_orders = _get_non_expired_orders(session=self._sesh)
         if not active_orders:
@@ -319,12 +383,8 @@ class CapellaConsoleClient:
 
         for ord in active_orders:
             granules = set([i["granuleId"] for i in ord["items"]])
-
             if granules.issuperset(stac_ids):
                 order_id = ord["orderId"]
-                logger.info(
-                    f'all stac ids ({", ".join(stac_ids)}) found in active order {order_id}'
-                )
                 break
         return order_id
 
@@ -366,7 +426,11 @@ class CapellaConsoleClient:
             return [item["assets"] for item in resp]
 
         stac_ids_set = set(stac_ids)
-        return [item["assets"] for item in resp if item["id"] in stac_ids_set]
+        return [
+            item["assets"]
+            for item in resp
+            if _derive_stac_id(item["assets"]) in stac_ids_set
+        ]
 
     def get_asset_bytesize(self, pre_signed_url: str) -> int:
         """get size in bytes of `pre_signed_url`"""
@@ -415,6 +479,7 @@ class CapellaConsoleClient:
         threaded: bool = True,
         show_progress: bool = False,
         separate_dirs: bool = True,
+        product_types: List[str] = None,
     ) -> Dict[str, Dict[str, Path]]:
         """
         download all assets of multiple products
@@ -454,6 +519,7 @@ class CapellaConsoleClient:
                                /tmp/<stac_id_1>.tif
                                /tmp/<stac_id_2>.tif
                                ...
+            product_types: filter by product type, e.g. ["SLC", "GEO"]
 
         Returns:
             Dict[str, Dict[str, Path]]: Local paths of downloaded files keyed by STAC id and asset type, e.g.
@@ -470,26 +536,35 @@ class CapellaConsoleClient:
         """
         local_dir = Path(local_dir)
 
-        one_of_equired = (assets_presigned, order_id, tasking_request_id, collect_id)
+        one_of_required = (assets_presigned, order_id, tasking_request_id, collect_id)
 
-        if not any(map(bool, one_of_equired)):
+        if not any(map(bool, one_of_required)):
             raise ValueError(
                 "please provide one of assets_presigned, order_id, tasking_request_id or collect_id"
             )
 
+        product_types = _validate_and_filter_product_types(product_types)
+        include = _validate_and_filter_asset_types(include)
+        exclude = _validate_and_filter_asset_types(exclude)
+
         if not assets_presigned:
             assets_presigned = self._resolve_assets_presigned(
-                order_id, tasking_request_id, collect_id
+                order_id, tasking_request_id, collect_id, product_types
             )
 
         len_assets_presigned = len(assets_presigned)
         suffix = "s" if len_assets_presigned > 1 else ""
         logger.info(f"downloading {len_assets_presigned} product{suffix}")
 
-        download_requests = []
-        by_stac_id = {}
+        # filter product_type
+        if product_types:
+            assets_presigned = _filter_assets_by_product_types(
+                assets_presigned, product_types
+            )
 
         # gather download requests
+        download_requests = []
+        by_stac_id = {}
         for cur_assets in assets_presigned:
             cur_download_requests = _gather_download_requests(
                 cur_assets, local_dir, include, exclude, separate_dirs
@@ -518,8 +593,11 @@ class CapellaConsoleClient:
         order_id: Optional[str] = None,
         tasking_request_id: Optional[str] = None,
         collect_id: Optional[str] = None,
+        product_types: List[str] = None,
     ) -> List[Dict[str, Any]]:
 
+        stac_ids = None
+
         # 1 - resolve assets_presigned from order_id
         if order_id:
             _validate_uuid(order_id)
@@ -527,15 +605,21 @@ class CapellaConsoleClient:
             # 2 - submit order for tasking_request_id
             if tasking_request_id:
                 _validate_uuid(tasking_request_id)
-                order_id = self._order_products_for_task(tasking_request_id)  # type: ignore
+                order_id, stac_ids = self._order_products_for_task(
+                    tasking_request_id, product_types
+                )  # type: ignore
             # 3 - submit order for collect_id
             else:
                 _validate_uuid(collect_id)
-                order_id = self._order_products_for_collect_ids(collect_ids=[collect_id])  # type: ignore
+                order_id, stac_ids = self._order_products_for_collect_ids(
+                    collect_ids=[collect_id], product_types=product_types  # type: ignore
+                )
 
-        return self.get_presigned_assets(order_id)  # type: ignore
+        return self.get_presigned_assets(order_id, stac_ids)  # type: ignore
 
-    def _order_products_for_task(self, tasking_request_id: str) -> str:
+    def _order_products_for_task(
+        self, tasking_request_id: str, product_types: List[str] = None
+    ) -> Tuple[str, List[str]]:
         """
         order all products associated with a tasking request
 
@@ -546,12 +630,27 @@ class CapellaConsoleClient:
         collect_ids = [
             coll["collectId"] for coll in self.get_collects_for_task(tasking_request_id)
         ]
-        return self._order_products_for_collect_ids(collect_ids)
+        return self._order_products_for_collect_ids(collect_ids, product_types)
 
-    def _order_products_for_collect_ids(self, collect_ids: List[str]) -> str:
-        stac_items = self.search(collect_id__in=collect_ids)
-        order_id = self.submit_order(items=stac_items, omit_search=True)
-        return order_id
+    def _order_products_for_collect_ids(
+        self, collect_ids: List[str], product_types: List[str] = None
+    ) -> Tuple[str, List[str]]:
+        search_kwargs = dict(
+            collect_id__in=collect_ids,
+        )
+        if product_types:
+            search_kwargs["product_type__in"] = product_types
+
+        stac_items = self.search(**search_kwargs)
+        if not stac_items:
+            logger.warning("No STAC items found ... aborting")
+            sys.exit(0)
+
+        order_id = self.submit_order(
+            items=stac_items, omit_search=True, check_active_orders=True
+        )
+        stac_ids = [i["id"] for i in stac_items]
+        return order_id, stac_ids
 
     def download_product(
         self,
@@ -607,6 +706,8 @@ class CapellaConsoleClient:
             _validate_uuid(order_id)
             assets_presigned = self._get_first_presigned_from_order(order_id)
 
+        include = _validate_and_filter_asset_types(include)
+        exclude = _validate_and_filter_asset_types(exclude)
         download_requests = _gather_download_requests(assets_presigned, local_dir, include, exclude)  # type: ignore
 
         if not download_requests:
